@@ -1,4 +1,4 @@
-#Copyright 2014-2022 MathWorks, Inc.
+#Copyright 2014-2025 MathWorks, Inc.
 
 """
 The MATLAB Engine enables you to call any MATLAB statement either synchronously
@@ -25,18 +25,30 @@ import importlib
 import atexit
 import weakref
 import threading
+import warnings
 
 # UPDATE_IF_PYTHON_VERSION_ADDED_OR_REMOVED : search for this string in codebase 
 # when support for a Python version must be added or removed
-_supported_versions = ['2_7', '3_8', '3_9', '3_10']
+
+_supported_versions = ['3_9', '3_10', '3_11', '3_12', '3_13']
 _ver = sys.version_info
 _version = '{0}_{1}'.format(_ver[0], _ver[1])
+_newer_than_supported = _ver[1] > 13
+
 _PYTHONVERSION = None
 
 if _version in _supported_versions:
     _PYTHONVERSION = _version
+elif _newer_than_supported:
+    warnings.warn('MATLAB Engine for Python supports Python version'
+                    ' 3.9, 3.10, 3.11, 3.12, and 3.13, but your version of Python '
+                    'is %s' % _version)
+    _PYTHONVERSION = _version
 else:
-    raise EnvironmentError("Python %s is not supported." % _version)
+    raise EnvironmentError('MATLAB Engine for Python supports Python version'
+                        ' 3.9, 3.10, 3.11, 3.12, and 3.13, but your version of Python '
+                        'is %s' % _version)
+
 
 _module_folder = os.path.dirname(os.path.realpath(__file__))
 _arch_filename = os.path.join(_module_folder, "_arch.txt")
@@ -44,7 +56,10 @@ success = False
 firstExceptionMessage = ''
 secondExceptionMessage = ''
 try:
-    pythonengine = importlib.import_module("matlabengineforpython"+_PYTHONVERSION)
+    if _PYTHONVERSION != '3_9' and _PYTHONVERSION != '3_10':
+        pythonengine = importlib.import_module("matlabengineforpython_abi3")
+    else:
+        pythonengine = importlib.import_module("matlabengineforpython" + _PYTHONVERSION)
 except Exception as firstE:
     firstExceptionMessage = str(firstE)
 
@@ -64,9 +79,11 @@ if firstExceptionMessage:
                 os.environ[_envs[_arch]] = _bin_dir + os.pathsep + os.environ[_envs[_arch]]
             else:
                 os.environ[_envs[_arch]] = _bin_dir
-            if sys.version_info.major >= 3 and sys.version_info.minor >= 8:
-                os.add_dll_directory(_bin_dir)
-        pythonengine = importlib.import_module("matlabengineforpython"+_PYTHONVERSION)
+            os.add_dll_directory(_bin_dir)
+        if _PYTHONVERSION != '3_9' or _PYTHONVERSION != '3_10':
+            pythonengine = importlib.import_module("matlabengineforpython_abi3")
+        else:
+            pythonengine = importlib.import_module("matlabengineforpython" + _PYTHONVERSION)
     except Exception as secondE:
         str1 = 'Please reinstall MATLAB Engine for Python or contact '
         str2 = 'MathWorks Technical Support for assistance:\nFirst issue: {}\nSecond issue: {}'.format(
@@ -107,9 +124,8 @@ def start_matlab(option="-nodesktop", **kwargs):
     
     Parameters
         option - MATLAB startup option.
-        async, background: bool - start MATLAB asynchronously or not.  This parameter
-        is optional and false by default.  "async" is a synonym for "background"
-        that will be removed in a future release.
+        background: bool - start MATLAB asynchronously or not.  This parameter
+        is optional and false by default.
                 
     Returns
         MatlabEngine - if aync or background is false.  This object can be used to evaluate
